#[non_exhaustive]pub struct PullRequest {
pub html_url: String,
pub number: u64,
pub title: String,
pub user: User,
pub created_at: DateTime<Utc>,
pub merged_at: Option<DateTime<Utc>>,
pub merged: bool,
pub merge_commit_sha: Option<String>,
pub base: ForkBranch,
pub head: ForkBranch,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.html_url: Stringnumber: u64title: Stringuser: Usercreated_at: DateTime<Utc>merged_at: Option<DateTime<Utc>>merged: boolmerge_commit_sha: Option<String>base: ForkBranchBase branch that the pull request is merged into
head: ForkBranchHead branch that the pull request is merged from